<?php
/**
 * @file
 * Defines module classes
 *
 * @ingroup xml_field
 * @{
 */

/*
 * Class xmlFieldXMLElement
 *
 * Allows for proper formatting of CDATA
 */
class xmlFieldXMLElement extends simpleXMLElement {

  public static $cdata_storage = array();


  /**
   * Return the actual cdata value; by $key if desired
   *
   * @param string $key
   *   E.g. [CDATA[0]] or just: 0
   */
  public function cdata($key = NULL) {
    if (empty(self::$cdata_storage) || $key === NULL) {
      return (array)self::$cdata_storage;
    }
    $key = is_numeric($key) ? "[CDATA[$key]]" : $key;
    return array_key_exists((string)$key, (array)self::$cdata_storage) ? self::$cdata_storage[$key] : NULL;
  }

  /**
   * Add a child element; this corrects CDATA issues
   */
  public function addChild($name, $value = NULL, $namespace = NULL) {
    // Move CDATA values to $cdata_storage and replace with token
    if (strpos($value, '<![CDATA[') === 0) {
      $id = count(self::$cdata_storage);
      $id = "[CDATA[$id]]";
      self::$cdata_storage[$id] = $value;
      $value = $id;
    }
    switch (func_num_args()) {
      case 1:
        return parent::addChild($name);
      case 2:
        return parent::addChild($name, $value);
      case 3:
        return parent::addChild($name, $value, $namespace);
    }
    //$parent = new ReflectionObject($this);
    //$parent_class = $parent->getParentClass();
    //$ref = new ReflectionMethod($parent_class, 'addChild');
    //$ref->invoke(new)

    // This broke in 5.2.x so the above is wonky but works - aklump
    // 02/08/2012 10:41:08
    //return call_user_func_array('parent::addChild', $args);
  }

  /**
   * Extends to allow chaining of add attribute
   *
   * e.g. $xml->addAttribute('size', 'large')->addAttribute('color', 'blue')
   */
  public function addAttribute($name, $value = NULL, $namespace = NULL) {
    switch (func_num_args()) {
      case 1:
        parent::addAttribute($name);
        break;
      case 2:
        parent::addAttribute($name, $value);
        break;
      case 3:
        parent::addAttribute($name, $value, $namespace);
        break;
    }
    return $this;
  }

  /**
   * Renders to xml, counterpart to the CDATA issue
   */
  public function asXML($filename = NULL) {
    switch (func_num_args()) {
      case 0:
        $string = parent::asXML();
        break;
      case 1:
        $string = parent::asXML($filename);
        break;
    }
    // Restore the cdata
    if (count(self::$cdata_storage) && preg_match_all('/\[CDATA\[(\d+)\]\]/', $string, $found)) {
      foreach ($found[0] as $id) {
        $string = str_replace($id, self::$cdata_storage[$id], $string);
      }
    }
    return $string;
  }
}

