<?php
/**
 * @file
 * API Description
 *
 * @ingroup xml_field
 * @{
 */

/**
 * Register XML Field API information.
 *
 * This is required for your module to have its include files loaded
 *
 * @return
 *   An array with the following possible keys:
 *   - api: (required) The version of the Views API the module implements.
 *   - path: (required) Where the default and schema files are saved.
 */
function hook_xml_field_api() {
  return array(
    'api' => 1,
    'path' => drupal_get_path('module', 'example') . '/includes/xml_field',
  );
}

/**
 * DEPRECATED!!! SEE /help/xml_field/using_files FOR MORE INFO
 *
 * Implements hook_xml_field_defaults().
 *
 * Be aware that if two modules are calling defaults for the same nid, the
   module with the heigher weight in the system table wins.
 *
 * @return array
 *   The array is keyed by nid. Each value is an array that mimics the field
     array structure of the node, e.g.
     $defaults[{nid}][{fieldname}]['und'][0]['xml'] = {default xml}
 */
function hook_xml_field_defaults() {
  $defaults = array();
  $defaults[3]['field_xml_metadata']['und'][0]['xml'] = "<page><button>Go to Home</button></page>";

  return $defaults;
}

/**
 * Implements hook_xml_field_validation_callbacks_alter().
 *
 * The callback will receive these args: $xml, $instance, &$message, &$args
 * - $xml string The XML that is being validated
 * - $instance array The field instance
 * - $message string Allows function to apply an error message to the test if
   needed. This will be passed through t() and should contain %title or @title
 * - $args array These args will be used with $message and t(); both @title and
   %title will be populated upon receipt
 *
 * The callback should return bool depending on validation
 */
function hook_xml_field_validation_callbacks_alter(&$callbacks) {
  $callbacks['my_module_xml_validator'] = array(
    'callback' => 'my_module_xml_validator',
    'title' => t('A superior xml validator'),
  );
}

/** @} */ //end of groupxml_field xml_field
